summaryrefslogtreecommitdiff
path: root/devel/electron35/files
diff options
context:
space:
mode:
Diffstat (limited to 'devel/electron35/files')
-rw-r--r--devel/electron35/files/patch-electron_filenames.gni4
-rw-r--r--devel/electron35/files/patch-electron_shell_browser_api_electron__api__base__window.cc4
-rw-r--r--devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.cc4
-rw-r--r--devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.h4
-rw-r--r--devel/electron35/files/patch-electron_shell_browser_native__window__views.cc48
-rw-r--r--devel/electron35/files/patch-electron_shell_browser_ui_file__dialog.h11
-rw-r--r--devel/electron35/files/patch-electron_spec_api-browser-window-spec.ts26
-rw-r--r--devel/electron35/files/patch-electron_spec_api-menu-spec.ts4
-rw-r--r--devel/electron35/files/patch-ui_gfx_x_atom__cache.cc4
-rw-r--r--devel/electron35/files/patch-ui_ozone_platform_x11_x11__window.cc4
-rw-r--r--devel/electron35/files/patch-ui_views_widget_desktop__aura_desktop__window__tree__host__platform.cc4
-rw-r--r--devel/electron35/files/patch-ui_views_widget_widget.cc4
-rw-r--r--devel/electron35/files/patch-v8_src_diagnostics_perf-jit.cc8
-rw-r--r--devel/electron35/files/patch-v8_src_diagnostics_perf-jit.h8
14 files changed, 74 insertions, 63 deletions
diff --git a/devel/electron35/files/patch-electron_filenames.gni b/devel/electron35/files/patch-electron_filenames.gni
index d9414e61828c..beb4f75dfee9 100644
--- a/devel/electron35/files/patch-electron_filenames.gni
+++ b/devel/electron35/files/patch-electron_filenames.gni
@@ -1,6 +1,6 @@
---- electron/filenames.gni.orig 2025-04-04 05:26:44 UTC
+--- electron/filenames.gni.orig 2025-05-06 23:52:46 UTC
+++ electron/filenames.gni
-@@ -237,8 +237,8 @@ filenames = {
+@@ -238,8 +238,8 @@ filenames = {
"shell/app/command_line_args.h",
"shell/app/electron_content_client.cc",
"shell/app/electron_content_client.h",
diff --git a/devel/electron35/files/patch-electron_shell_browser_api_electron__api__base__window.cc b/devel/electron35/files/patch-electron_shell_browser_api_electron__api__base__window.cc
index ff576883918c..ad66ab5b7120 100644
--- a/devel/electron35/files/patch-electron_shell_browser_api_electron__api__base__window.cc
+++ b/devel/electron35/files/patch-electron_shell_browser_api_electron__api__base__window.cc
@@ -1,4 +1,4 @@
---- electron/shell/browser/api/electron_api_base_window.cc.orig 2025-04-17 14:56:35 UTC
+--- electron/shell/browser/api/electron_api_base_window.cc.orig 2025-05-06 23:52:46 UTC
+++ electron/shell/browser/api/electron_api_base_window.cc
@@ -41,7 +41,7 @@
#include "shell/browser/ui/views/win_frame_view.h"
@@ -27,7 +27,7 @@
void BaseWindow::SetTitleBarOverlay(const gin_helper::Dictionary& options,
gin_helper::Arguments* args) {
// Ensure WCO is already enabled on this window
-@@ -1332,7 +1332,7 @@ void BaseWindow::BuildPrototype(v8::Isolate* isolate,
+@@ -1334,7 +1334,7 @@ void BaseWindow::BuildPrototype(v8::Isolate* isolate,
.SetMethod("setThumbnailToolTip", &BaseWindow::SetThumbnailToolTip)
.SetMethod("setAppDetails", &BaseWindow::SetAppDetails)
#endif
diff --git a/devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.cc b/devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.cc
index b67763f0b52d..5c120f0b85f8 100644
--- a/devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.cc
+++ b/devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.cc
@@ -1,4 +1,4 @@
---- electron/shell/browser/api/electron_api_web_contents.cc.orig 2025-04-17 14:56:35 UTC
+--- electron/shell/browser/api/electron_api_web_contents.cc.orig 2025-05-06 23:52:46 UTC
+++ electron/shell/browser/api/electron_api_web_contents.cc
@@ -159,11 +159,11 @@
#include "ui/base/cocoa/defaults_utils.h"
@@ -66,7 +66,7 @@
if (owner_window())
owner_window()->Focus(true);
#endif
-@@ -4311,7 +4311,7 @@ ui::ImageModel WebContents::GetDevToolsWindowIcon() {
+@@ -4319,7 +4319,7 @@ ui::ImageModel WebContents::GetDevToolsWindowIcon() {
}
#endif
diff --git a/devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.h b/devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.h
index f3734fc1dfa0..b489d322ba0e 100644
--- a/devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.h
+++ b/devel/electron35/files/patch-electron_shell_browser_api_electron__api__web__contents.h
@@ -1,6 +1,6 @@
---- electron/shell/browser/api/electron_api_web_contents.h.orig 2025-04-04 05:26:44 UTC
+--- electron/shell/browser/api/electron_api_web_contents.h.orig 2025-05-06 23:52:46 UTC
+++ electron/shell/browser/api/electron_api_web_contents.h
-@@ -783,7 +783,7 @@ class WebContents final : public ExclusiveAccessContex
+@@ -784,7 +784,7 @@ class WebContents final : public ExclusiveAccessContex
#if defined(TOOLKIT_VIEWS) && !BUILDFLAG(IS_MAC)
ui::ImageModel GetDevToolsWindowIcon() override;
#endif
diff --git a/devel/electron35/files/patch-electron_shell_browser_native__window__views.cc b/devel/electron35/files/patch-electron_shell_browser_native__window__views.cc
index 2d17cb915ce4..c5d4c6cf8088 100644
--- a/devel/electron35/files/patch-electron_shell_browser_native__window__views.cc
+++ b/devel/electron35/files/patch-electron_shell_browser_native__window__views.cc
@@ -1,6 +1,6 @@
---- electron/shell/browser/native_window_views.cc.orig 2025-04-17 14:56:35 UTC
+--- electron/shell/browser/native_window_views.cc.orig 2025-05-13 12:56:52 UTC
+++ electron/shell/browser/native_window_views.cc
-@@ -50,7 +50,7 @@
+@@ -51,7 +51,7 @@
#include "ui/wm/core/shadow_types.h"
#include "ui/wm/core/window_util.h"
@@ -9,7 +9,7 @@
#include "base/strings/string_util.h"
#include "shell/browser/browser.h"
#include "shell/browser/linux/unity_service.h"
-@@ -295,7 +295,7 @@ NativeWindowViews::NativeWindowViews(const gin_helper:
+@@ -296,7 +296,7 @@ NativeWindowViews::NativeWindowViews(const gin_helper:
params.parent = parent->GetNativeWindow();
params.native_widget = new ElectronDesktopNativeWidgetAura(this);
@@ -18,7 +18,7 @@
std::string name = Browser::Get()->GetName();
// Set WM_WINDOW_ROLE.
params.wm_role_name = "browser-window";
-@@ -321,7 +321,7 @@ NativeWindowViews::NativeWindowViews(const gin_helper:
+@@ -322,7 +322,7 @@ NativeWindowViews::NativeWindowViews(const gin_helper:
std::string window_type;
options.Get(options::kType, &window_type);
@@ -27,7 +27,7 @@
// Set _GTK_THEME_VARIANT to dark if we have "dark-theme" option set.
bool use_dark_theme = false;
if (options.Get(options::kDarkTheme, &use_dark_theme) && use_dark_theme) {
-@@ -427,7 +427,7 @@ NativeWindowViews::NativeWindowViews(const gin_helper:
+@@ -431,7 +431,7 @@ NativeWindowViews::NativeWindowViews(const gin_helper:
if (window)
window->AddPreTargetHandler(this);
@@ -36,7 +36,7 @@
// On linux after the widget is initialized we might have to force set the
// bounds if the bounds are smaller than the current display
SetBounds(gfx::Rect(GetPosition(), bounds.size()), false);
-@@ -463,7 +463,7 @@ void NativeWindowViews::SetGTKDarkThemeEnabled(bool us
+@@ -467,7 +467,7 @@ void NativeWindowViews::SetGTKDarkThemeEnabled(bool us
}
void NativeWindowViews::SetGTKDarkThemeEnabled(bool use_dark_theme) {
@@ -45,7 +45,7 @@
if (IsX11()) {
const std::string color = use_dark_theme ? "dark" : "light";
auto* connection = x11::Connection::Get();
-@@ -525,7 +525,7 @@ void NativeWindowViews::Show() {
+@@ -529,7 +529,7 @@ void NativeWindowViews::Show() {
NotifyWindowShow();
@@ -54,7 +54,7 @@
if (global_menu_bar_)
global_menu_bar_->OnWindowMapped();
-@@ -541,7 +541,7 @@ void NativeWindowViews::ShowInactive() {
+@@ -545,7 +545,7 @@ void NativeWindowViews::ShowInactive() {
NotifyWindowShow();
@@ -63,7 +63,7 @@
if (global_menu_bar_)
global_menu_bar_->OnWindowMapped();
-@@ -560,7 +560,7 @@ void NativeWindowViews::Hide() {
+@@ -564,7 +564,7 @@ void NativeWindowViews::Hide() {
NotifyWindowHide();
@@ -72,7 +72,7 @@
if (global_menu_bar_)
global_menu_bar_->OnWindowUnmapped();
#endif
-@@ -591,7 +591,7 @@ bool NativeWindowViews::IsEnabled() const {
+@@ -595,7 +595,7 @@ bool NativeWindowViews::IsEnabled() const {
bool NativeWindowViews::IsEnabled() const {
#if BUILDFLAG(IS_WIN)
return ::IsWindowEnabled(GetAcceleratedWidget());
@@ -81,7 +81,7 @@
if (IsX11())
return !event_disabler_.get();
NOTIMPLEMENTED();
-@@ -831,7 +831,7 @@ void NativeWindowViews::SetBounds(const gfx::Rect& bou
+@@ -845,7 +845,7 @@ void NativeWindowViews::SetBounds(const gfx::Rect& bou
}
#endif
@@ -90,7 +90,7 @@
// On Linux and Windows the minimum and maximum size should be updated with
// window size when window is not resizable.
if (!resizable_) {
-@@ -1089,7 +1089,7 @@ bool NativeWindowViews::IsClosable() const {
+@@ -1103,7 +1103,7 @@ bool NativeWindowViews::IsClosable() const {
return false;
}
return !(info.fState & MFS_DISABLED);
@@ -99,7 +99,7 @@
return true;
#endif
}
-@@ -1129,7 +1129,7 @@ void NativeWindowViews::Center() {
+@@ -1143,7 +1143,7 @@ void NativeWindowViews::Center() {
// for now to avoid breaking API contract, but should consider the long
// term plan for this aligning with upstream.
void NativeWindowViews::Center() {
@@ -108,7 +108,7 @@
auto display =
display::Screen::GetScreen()->GetDisplayNearestWindow(GetNativeWindow());
gfx::Rect window_bounds_in_screen = display.work_area();
-@@ -1352,7 +1352,7 @@ void NativeWindowViews::SetMenu(ElectronMenuModel* men
+@@ -1367,7 +1367,7 @@ void NativeWindowViews::SetMenu(ElectronMenuModel* men
}
void NativeWindowViews::SetMenu(ElectronMenuModel* menu_model) {
@@ -117,7 +117,7 @@
// Remove global menu bar.
if (global_menu_bar_ && menu_model == nullptr) {
global_menu_bar_.reset();
-@@ -1407,7 +1407,7 @@ void NativeWindowViews::SetParentWindow(NativeWindow*
+@@ -1422,7 +1422,7 @@ void NativeWindowViews::SetParentWindow(NativeWindow*
void NativeWindowViews::SetParentWindow(NativeWindow* parent) {
NativeWindow::SetParentWindow(parent);
@@ -126,7 +126,7 @@
if (IsX11()) {
auto* connection = x11::Connection::Get();
connection->SetProperty(
-@@ -1453,7 +1453,7 @@ void NativeWindowViews::SetProgressBar(double progress
+@@ -1468,7 +1468,7 @@ void NativeWindowViews::SetProgressBar(double progress
NativeWindow::ProgressState state) {
#if BUILDFLAG(IS_WIN)
taskbar_host_.SetProgressBar(GetAcceleratedWidget(), progress, state);
@@ -135,16 +135,16 @@
if (unity::IsRunning()) {
unity::SetProgressFraction(progress);
}
-@@ -1524,7 +1524,7 @@ bool NativeWindowViews::IsVisibleOnAllWorkspaces() con
- }
+@@ -1546,7 +1546,7 @@ bool NativeWindowViews::IsVisibleOnAllWorkspaces() con
+ if (const auto* view_native_widget = widget()->native_widget_private())
+ return view_native_widget->IsVisibleOnAllWorkspaces();
- bool NativeWindowViews::IsVisibleOnAllWorkspaces() const {
-#if BUILDFLAG(IS_LINUX)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)
if (IsX11()) {
// Use the presence/absence of _NET_WM_STATE_STICKY in _NET_WM_STATE to
// determine whether the current window is visible on all workspaces.
-@@ -1547,7 +1547,7 @@ content::DesktopMediaID NativeWindowViews::GetDesktopM
+@@ -1569,7 +1569,7 @@ content::DesktopMediaID NativeWindowViews::GetDesktopM
#if BUILDFLAG(IS_WIN)
window_handle =
reinterpret_cast<content::DesktopMediaID::Id>(accelerated_widget);
@@ -153,7 +153,7 @@
window_handle = static_cast<uint32_t>(accelerated_widget);
#endif
aura::WindowTreeHost* const host =
-@@ -1645,7 +1645,7 @@ void NativeWindowViews::SetIcon(HICON window_icon, HIC
+@@ -1667,7 +1667,7 @@ void NativeWindowViews::SetIcon(HICON window_icon, HIC
SendMessage(hwnd, WM_SETICON, ICON_BIG,
reinterpret_cast<LPARAM>(app_icon_.get()));
}
@@ -162,7 +162,7 @@
void NativeWindowViews::SetIcon(const gfx::ImageSkia& icon) {
auto* tree_host = views::DesktopWindowTreeHostLinux::GetHostForWidget(
GetAcceleratedWidget());
-@@ -1741,7 +1741,7 @@ bool NativeWindowViews::CanMinimize() const {
+@@ -1763,7 +1763,7 @@ bool NativeWindowViews::CanMinimize() const {
bool NativeWindowViews::CanMinimize() const {
#if BUILDFLAG(IS_WIN)
return minimizable_;
@@ -171,7 +171,7 @@
return true;
#endif
}
-@@ -1797,7 +1797,7 @@ void NativeWindowViews::HandleKeyboardEvent(
+@@ -1819,7 +1819,7 @@ void NativeWindowViews::HandleKeyboardEvent(
if (widget_destroyed_)
return;
@@ -180,7 +180,7 @@
if (event.windows_key_code == ui::VKEY_BROWSER_BACK)
NotifyWindowExecuteAppCommand(kBrowserBackward);
else if (event.windows_key_code == ui::VKEY_BROWSER_FORWARD)
-@@ -1816,7 +1816,7 @@ void NativeWindowViews::OnMouseEvent(ui::MouseEvent* e
+@@ -1838,7 +1838,7 @@ void NativeWindowViews::OnMouseEvent(ui::MouseEvent* e
// Alt+Click should not toggle menu bar.
root_view_.ResetAltState();
diff --git a/devel/electron35/files/patch-electron_shell_browser_ui_file__dialog.h b/devel/electron35/files/patch-electron_shell_browser_ui_file__dialog.h
new file mode 100644
index 000000000000..dccc81864b78
--- /dev/null
+++ b/devel/electron35/files/patch-electron_shell_browser_ui_file__dialog.h
@@ -0,0 +1,11 @@
+--- electron/shell/browser/ui/file_dialog.h.orig 2025-05-10 23:09:28 UTC
++++ electron/shell/browser/ui/file_dialog.h
+@@ -77,7 +77,7 @@ void ShowSaveDialog(const DialogSettings& settings,
+ void ShowSaveDialog(const DialogSettings& settings,
+ gin_helper::Promise<gin_helper::Dictionary> promise);
+
+-#if BUILDFLAG(IS_LINUX)
++#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)
+ // Rewrite of SelectFileDialogLinuxPortal equivalent functions with primary
+ // difference being that dbus_thread_linux::GetSharedSessionBus is not used
+ // so that version detection can be initiated and compeleted on the dbus thread
diff --git a/devel/electron35/files/patch-electron_spec_api-browser-window-spec.ts b/devel/electron35/files/patch-electron_spec_api-browser-window-spec.ts
index 7747ff6553cc..5de2e6e8c6d7 100644
--- a/devel/electron35/files/patch-electron_spec_api-browser-window-spec.ts
+++ b/devel/electron35/files/patch-electron_spec_api-browser-window-spec.ts
@@ -1,4 +1,4 @@
---- electron/spec/api-browser-window-spec.ts.orig 2025-04-17 14:56:35 UTC
+--- electron/spec/api-browser-window-spec.ts.orig 2025-05-13 12:56:52 UTC
+++ electron/spec/api-browser-window-spec.ts
@@ -69,7 +69,7 @@ describe('BrowserWindow module', () => {
}).not.to.throw();
@@ -72,7 +72,7 @@
it('checks normal bounds when minimized', async () => {
const bounds = w.getBounds();
const minimize = once(w, 'minimize');
-@@ -2985,7 +2985,7 @@ describe('BrowserWindow module', () => {
+@@ -2986,7 +2986,7 @@ describe('BrowserWindow module', () => {
describe('BrowserWindow.setOpacity(opacity)', () => {
afterEach(closeAllWindows);
@@ -81,7 +81,7 @@
it('make window with initial opacity', () => {
const w = new BrowserWindow({ show: false, opacity: 0.5 });
expect(w.getOpacity()).to.equal(0.5);
-@@ -3011,7 +3011,7 @@ describe('BrowserWindow module', () => {
+@@ -3012,7 +3012,7 @@ describe('BrowserWindow module', () => {
});
});
@@ -90,7 +90,7 @@
it('sets 1 regardless of parameter', () => {
const w = new BrowserWindow({ show: false });
w.setOpacity(0);
-@@ -3222,7 +3222,7 @@ describe('BrowserWindow module', () => {
+@@ -3223,7 +3223,7 @@ describe('BrowserWindow module', () => {
expect(overlayRectPreMax.height).to.equal(size);
// 'maximize' event is not emitted on Linux in CI.
@@ -99,7 +99,7 @@
const maximize = once(w, 'maximize');
w.show();
w.maximize();
-@@ -3288,7 +3288,7 @@ describe('BrowserWindow module', () => {
+@@ -3289,7 +3289,7 @@ describe('BrowserWindow module', () => {
expect(preMaxHeight).to.equal(size);
// 'maximize' event is not emitted on Linux in CI.
@@ -108,7 +108,7 @@
const maximize = once(w, 'maximize');
w.show();
w.maximize();
-@@ -3953,7 +3953,7 @@ describe('BrowserWindow module', () => {
+@@ -3954,7 +3954,7 @@ describe('BrowserWindow module', () => {
expect(test.nodeTimers).to.equal(true);
expect(test.nodeUrl).to.equal(true);
@@ -117,7 +117,7 @@
expect(test.creationTime).to.be.null('creation time');
expect(test.systemMemoryInfo).to.be.null('system memory info');
} else {
-@@ -4458,7 +4458,7 @@ describe('BrowserWindow module', () => {
+@@ -4459,7 +4459,7 @@ describe('BrowserWindow module', () => {
});
});
@@ -126,7 +126,7 @@
afterEach(closeAllWindows);
it('emits an event when window is maximized', async () => {
const w = new BrowserWindow({ show: false });
-@@ -4729,7 +4729,7 @@ describe('BrowserWindow module', () => {
+@@ -4730,7 +4730,7 @@ describe('BrowserWindow module', () => {
// TODO(zcbenz):
// This test does not run on Linux CI. See:
// https://github.com/electron/electron/issues/28699
@@ -135,7 +135,7 @@
const w = new BrowserWindow({});
const maximize = once(w, 'maximize');
w.maximize();
-@@ -4746,7 +4746,7 @@ describe('BrowserWindow module', () => {
+@@ -4747,7 +4747,7 @@ describe('BrowserWindow module', () => {
});
// TODO(dsanders11): Enable once maximize event works on Linux again on CI
@@ -144,7 +144,7 @@
afterEach(closeAllWindows);
it('should show the window if it is not currently shown', async () => {
const w = new BrowserWindow({ show: false });
-@@ -4783,7 +4783,7 @@ describe('BrowserWindow module', () => {
+@@ -4784,7 +4784,7 @@ describe('BrowserWindow module', () => {
// TODO(dsanders11): Enable once minimize event works on Linux again.
// See https://github.com/electron/electron/issues/28699
@@ -153,7 +153,7 @@
const w = new BrowserWindow();
const minimize = once(w, 'minimize');
w.minimize();
-@@ -5269,7 +5269,7 @@ describe('BrowserWindow module', () => {
+@@ -5270,7 +5270,7 @@ describe('BrowserWindow module', () => {
});
// On Linux there is no "resizable" property of a window.
@@ -162,7 +162,7 @@
const w = new BrowserWindow({ show: false });
expect(w.resizable).to.be.true('resizable');
-@@ -5408,7 +5408,7 @@ describe('BrowserWindow module', () => {
+@@ -5480,7 +5480,7 @@ describe('BrowserWindow module', () => {
});
});
@@ -171,7 +171,7 @@
// Not implemented on Linux.
afterEach(closeAllWindows);
-@@ -6678,7 +6678,7 @@ describe('BrowserWindow module', () => {
+@@ -6679,7 +6679,7 @@ describe('BrowserWindow module', () => {
describe('"transparent" option', () => {
afterEach(closeAllWindows);
diff --git a/devel/electron35/files/patch-electron_spec_api-menu-spec.ts b/devel/electron35/files/patch-electron_spec_api-menu-spec.ts
index 0929780b9795..2d4a1fa635e6 100644
--- a/devel/electron35/files/patch-electron_spec_api-menu-spec.ts
+++ b/devel/electron35/files/patch-electron_spec_api-menu-spec.ts
@@ -1,6 +1,6 @@
---- electron/spec/api-menu-spec.ts.orig 2024-10-09 13:53:06 UTC
+--- electron/spec/api-menu-spec.ts.orig 2025-05-06 23:52:46 UTC
+++ electron/spec/api-menu-spec.ts
-@@ -890,7 +890,7 @@ describe('Menu module', function () {
+@@ -891,7 +891,7 @@ describe('Menu module', function () {
// https://github.com/electron/electron/issues/35724
// Maximizing window is enough to trigger the bug
// FIXME(dsanders11): Test always passes on CI, even pre-fix
diff --git a/devel/electron35/files/patch-ui_gfx_x_atom__cache.cc b/devel/electron35/files/patch-ui_gfx_x_atom__cache.cc
index 63790e9c9a27..4e8b2af8ab90 100644
--- a/devel/electron35/files/patch-ui_gfx_x_atom__cache.cc
+++ b/devel/electron35/files/patch-ui_gfx_x_atom__cache.cc
@@ -1,6 +1,6 @@
---- ui/gfx/x/atom_cache.cc.orig 2025-01-27 17:37:37 UTC
+--- ui/gfx/x/atom_cache.cc.orig 2025-05-15 12:22:59 UTC
+++ ui/gfx/x/atom_cache.cc
-@@ -155,6 +155,7 @@ constexpr auto kAtomsToCache = std::to_array<const cha
+@@ -156,6 +156,7 @@ constexpr auto kAtomsToCache = std::to_array<const cha
"application/octet-stream",
"application/vnd.chromium.test",
"chromium/filename",
diff --git a/devel/electron35/files/patch-ui_ozone_platform_x11_x11__window.cc b/devel/electron35/files/patch-ui_ozone_platform_x11_x11__window.cc
index 9899581d8db2..d0d4846780cb 100644
--- a/devel/electron35/files/patch-ui_ozone_platform_x11_x11__window.cc
+++ b/devel/electron35/files/patch-ui_ozone_platform_x11_x11__window.cc
@@ -1,6 +1,6 @@
---- ui/ozone/platform/x11/x11_window.cc.orig 2025-01-27 17:37:37 UTC
+--- ui/ozone/platform/x11/x11_window.cc.orig 2025-05-15 12:22:59 UTC
+++ ui/ozone/platform/x11/x11_window.cc
-@@ -1502,7 +1502,7 @@ void X11Window::OnXWindowStateChanged() {
+@@ -1509,7 +1509,7 @@ void X11Window::OnXWindowStateChanged() {
WindowTiledEdges tiled_state = GetTiledState();
if (tiled_state != tiled_state_) {
tiled_state_ = tiled_state;
diff --git a/devel/electron35/files/patch-ui_views_widget_desktop__aura_desktop__window__tree__host__platform.cc b/devel/electron35/files/patch-ui_views_widget_desktop__aura_desktop__window__tree__host__platform.cc
index 69891b8bc56a..2b89e9b60d12 100644
--- a/devel/electron35/files/patch-ui_views_widget_desktop__aura_desktop__window__tree__host__platform.cc
+++ b/devel/electron35/files/patch-ui_views_widget_desktop__aura_desktop__window__tree__host__platform.cc
@@ -1,4 +1,4 @@
---- ui/views/widget/desktop_aura/desktop_window_tree_host_platform.cc.orig 2025-03-24 20:50:14 UTC
+--- ui/views/widget/desktop_aura/desktop_window_tree_host_platform.cc.orig 2025-05-15 12:22:59 UTC
+++ ui/views/widget/desktop_aura/desktop_window_tree_host_platform.cc
@@ -50,7 +50,7 @@
#include "ui/wm/core/window_util.h"
@@ -18,7 +18,7 @@
std::make_unique<DesktopDragDropClientOzoneLinux>(window(), drag_handler);
#else
std::make_unique<DesktopDragDropClientOzone>(window(), drag_handler);
-@@ -1174,7 +1174,7 @@ bool DesktopWindowTreeHostPlatform::RotateFocusForWidg
+@@ -1179,7 +1179,7 @@ bool DesktopWindowTreeHostPlatform::RotateFocusForWidg
// DesktopWindowTreeHost:
// Linux subclasses this host and adds some Linux specific bits.
diff --git a/devel/electron35/files/patch-ui_views_widget_widget.cc b/devel/electron35/files/patch-ui_views_widget_widget.cc
index bda30113f082..a7ef80a3b525 100644
--- a/devel/electron35/files/patch-ui_views_widget_widget.cc
+++ b/devel/electron35/files/patch-ui_views_widget_widget.cc
@@ -1,4 +1,4 @@
---- ui/views/widget/widget.cc.orig 2025-03-24 20:50:14 UTC
+--- ui/views/widget/widget.cc.orig 2025-05-15 12:22:59 UTC
+++ ui/views/widget/widget.cc
@@ -63,7 +63,7 @@
#include "ui/views/window/custom_frame_view.h"
@@ -9,7 +9,7 @@
#include "ui/linux/linux_ui.h"
#endif
-@@ -2444,7 +2444,7 @@ const ui::NativeTheme* Widget::GetNativeTheme() const
+@@ -2450,7 +2450,7 @@ const ui::NativeTheme* Widget::GetNativeTheme() const
return parent_->GetNativeTheme();
}
diff --git a/devel/electron35/files/patch-v8_src_diagnostics_perf-jit.cc b/devel/electron35/files/patch-v8_src_diagnostics_perf-jit.cc
index 8ff9f89da4d4..8047bb29a79f 100644
--- a/devel/electron35/files/patch-v8_src_diagnostics_perf-jit.cc
+++ b/devel/electron35/files/patch-v8_src_diagnostics_perf-jit.cc
@@ -1,11 +1,11 @@
---- v8/src/diagnostics/perf-jit.cc.orig 2023-10-19 20:00:39 UTC
+--- v8/src/diagnostics/perf-jit.cc.orig 2025-05-10 23:04:03 UTC
+++ v8/src/diagnostics/perf-jit.cc
@@ -31,7 +31,7 @@
#include "src/flags/flags.h"
- // Only compile the {LinuxPerfJitLogger} on Linux.
--#if V8_OS_LINUX
-+#if defined(V8_OS_LINUX) || defined(V8_OS_BSD)
+ // Only compile the {PerfJitLogger} on Linux & Darwin.
+-#if V8_OS_LINUX || V8_OS_DARWIN
++#if defined(V8_OS_LINUX) || defined(V8_OS_DARWIN) || defined(V8_OS_BSD)
#include <fcntl.h>
#include <sys/mman.h>
diff --git a/devel/electron35/files/patch-v8_src_diagnostics_perf-jit.h b/devel/electron35/files/patch-v8_src_diagnostics_perf-jit.h
index b5c06ad88b32..4981acef4fc9 100644
--- a/devel/electron35/files/patch-v8_src_diagnostics_perf-jit.h
+++ b/devel/electron35/files/patch-v8_src_diagnostics_perf-jit.h
@@ -1,11 +1,11 @@
---- v8/src/diagnostics/perf-jit.h.orig 2022-06-17 14:20:10 UTC
+--- v8/src/diagnostics/perf-jit.h.orig 2025-05-10 23:04:03 UTC
+++ v8/src/diagnostics/perf-jit.h
@@ -31,7 +31,7 @@
#include "include/v8config.h"
- // {LinuxPerfJitLogger} is only implemented on Linux.
--#if V8_OS_LINUX
-+#if defined(V8_OS_LINUX) || defined(V8_OS_BSD)
+ // {PerfJitLogger} is only implemented on Linux & Darwin.
+-#if V8_OS_LINUX || V8_OS_DARWIN
++#if defined(V8_OS_LINUX) || defined(V8_OS_DARWIN) || defined(V8_OS_BSD)
#include "src/logging/log.h"